.. Xbox-Smartglass-Core documentation master file, created by
   sphinx-quickstart on Fri Mar  9 14:30:41 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Xbox-Smartglass-Core's documentation!
================================================

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   source/xbox.sg.console
   source/xbox.sg.manager
   source/xbox.sg.protocol
   source/xbox.sg.crypto
   source/xbox.sg.factory
   source/xbox.scripts
   source/xbox.auxiliary
   source/xbox.stump

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
